@@ -82,7 +82,7 @@ AnimationWidget::AnimationWidget(std::shared_ptr<AssetParameterModel> model, QMo
     }
     m_monitorSize = pCore->getCurrentFrameSize();
     m_monitor = pCore->getMonitor(m_model->monitorId);
-    m_timePos = new TimecodeDisplay(m_monitor->timecode(), this);
+    m_timePos = new TimecodeDisplay(pCore->timecode(), this);
     m_ruler = new AnimKeyframeRuler(0, m_outPoint - m_inPoint, this);
     connect(m_ruler, &AnimKeyframeRuler::addKeyframe, this, &AnimationWidget::slotAddKeyframe);
     connect(m_ruler, &AnimKeyframeRuler::removeKeyframe, this, &AnimationWidget::slotDeleteKeyframe);
