@@ -21,6 +21,7 @@
 #include "assets/keyframes/model/corners/cornershelper.hpp"
 #include "assets/keyframes/model/keyframemodellist.hpp"
 #include "assets/keyframes/model/rotoscoping/rotohelper.hpp"
+#include "assets/keyframes/model/keyframemonitorhelper.hpp"
 #include "assets/keyframes/view/keyframeview.hpp"
 #include "assets/model/assetparametermodel.hpp"
 #include "assets/view/widgets/keyframeimport.h"
@@ -97,6 +98,8 @@ KeyframeWidget::KeyframeWidget(std::shared_ptr<AssetParameterModel> model, QMode
     m_toolbar = new QToolBar(this);
 
     Monitor *monitor = pCore->getMonitor(m_model->monitorId);
+    connect(monitor, &Monitor::seekPosition, this, &KeyframeWidget::monitorSeek, Qt::UniqueConnection);
+    connect(monitor, &Monitor::seekToKeyframe, this, &KeyframeWidget::slotSeekToKeyframe, Qt::UniqueConnection);
     m_time = new TimecodeDisplay(pCore->timecode(), this);
     m_time->setRange(0, duration - 1);
 
@@ -341,10 +344,11 @@ void KeyframeWidget::addParameter(const QPersistentModelIndex &index)
         int inPos = m_model->data(index, AssetParameterModel::ParentInRole).toInt();
         QPair<int, int> range(inPos, inPos + m_model->data(index, AssetParameterModel::ParentDurationRole).toInt());
         const QString value = m_keyframes->getInterpolatedValue(getPosition(), index).toString();
+        m_monitorHelper = new KeyframeMonitorHelper(pCore->getMonitor(m_model->monitorId), m_model, index, this);
         QRect rect;
         double opacity = 0;
         QStringList vals = value.split(QLatin1Char(' '));
-        if (vals.count() >= 4) {
+        if (vals.count() > 3) {
             rect = QRect(vals.at(0).toInt(), vals.at(1).toInt(), vals.at(2).toInt(), vals.at(3).toInt());
             if (vals.count() > 4) {
                 opacity = locale.toDouble(vals.at(4));
@@ -411,11 +415,6 @@ void KeyframeWidget::slotInitMonitor(bool active)
         connect(monitor, &Monitor::updateScene, m_keyframeview, &KeyframeView::slotModelChanged, Qt::UniqueConnection);
     }
     connectMonitor(active);
-    if (active) {
-        connect(monitor, &Monitor::seekPosition, this, &KeyframeWidget::monitorSeek, Qt::UniqueConnection);
-    } else {
-        disconnect(monitor, &Monitor::seekPosition, this, &KeyframeWidget::monitorSeek);
-    }
 }
 
 void KeyframeWidget::connectMonitor(bool active)
@@ -510,3 +509,10 @@ void KeyframeWidget::slotRemoveNextKeyframes()
     int pos = m_time->getValue() + m_model->data(m_index, AssetParameterModel::ParentInRole).toInt();
     m_keyframes->removeNextKeyframes(GenTime(pos, pCore->getCurrentFps()));
 }
+
+
+void KeyframeWidget::slotSeekToKeyframe(int ix)
+{
+    int pos = m_keyframes->getPosAtIndex(ix).frames(pCore->getCurrentFps());
+    slotSetPosition(pos, true);
+}
