@@ -24,6 +24,60 @@ the Free Software Foundation, either version 3 of the License, or
 #include <QStandardPaths>
 #include <mlt++/MltFactory.h>
 #include <mlt++/MltRepository.h>
+#include <framework/mlt_log.h>
+
+static void mlt_log_handler(void *service, int mlt_level, const char *format, va_list args)
+{
+    if (mlt_level > mlt_log_get_level())
+        return;
+
+    /*enum Logger::LogLevel cuteLoggerLevel = Logger::Fatal;
+    switch (mlt_level) {
+    case MLT_LOG_DEBUG:
+        cuteLoggerLevel = Logger::Trace;
+        break;
+    case MLT_LOG_ERROR:
+    case MLT_LOG_FATAL:
+    case MLT_LOG_PANIC:
+        cuteLoggerLevel = Logger::Error;
+        break;
+    case MLT_LOG_INFO:
+        cuteLoggerLevel = Logger::Info;
+        break;
+    case MLT_LOG_VERBOSE:
+        cuteLoggerLevel = Logger::Debug;
+        break;
+    case MLT_LOG_WARNING:
+        cuteLoggerLevel = Logger::Warning;
+        break;
+    }*/
+    QString message;
+    mlt_properties properties = service? MLT_SERVICE_PROPERTIES((mlt_service) service) : NULL;
+    if (properties) {
+        char *mlt_type = mlt_properties_get(properties, "mlt_type");
+        char *service_name = mlt_properties_get(properties, "mlt_service");
+        char *resource = mlt_properties_get(properties, "resource");
+        char *id = mlt_properties_get(properties, "id");
+        if (!resource || resource[0] != '<' || resource[strlen(resource) - 1] != '>')
+            mlt_type = mlt_properties_get(properties, "mlt_type" );
+        if (service_name)
+            message = QString("[%1 %2 %3] ").arg(mlt_type).arg(service_name).arg(id);
+        else
+            message = QString::asprintf("[%s %p] ", mlt_type, service);
+        if (resource)
+            message.append(QString("\"%1\" ").arg(resource));
+        message.append(QString::vasprintf(format, args));
+        message.replace('\n', "");
+        if (!strcmp(mlt_type, "filter")) {
+            pCore->processInvalidFilter(service_name, id, message);
+        }
+    } else {
+        message = QString::vasprintf(format, args);
+        message.replace('\n', "");
+    }
+    qDebug()<<"==========\n\nMLT ERROR:\n"<<message<<"\n";
+}
+
 
 std::unique_ptr<MltConnection> MltConnection::m_self;
 MltConnection::MltConnection(const QString &mltPath)
@@ -43,7 +97,8 @@ MltConnection::MltConnection(const QString &mltPath)
         producersList << producers->get_name(i);
     }
     KdenliveSettings::setProducerslist(producersList);
-
+    mlt_log_set_level(MLT_LOG_WARNING);
+    mlt_log_set_callback(mlt_log_handler);
     refreshLumas();
 }
 
