@@ -141,6 +141,8 @@ public:
     void setConsumerProperty(const QString &name, const QString &value);
     /** @brief Clear consumer cache */
     void purgeCache();
+    /** @brief Show / hide monitor ruler */
+    void switchRuler(bool show);
 
 protected:
     void mouseReleaseEvent(QMouseEvent *event) override;
@@ -148,6 +150,7 @@ protected:
     void wheelEvent(QWheelEvent *event) override;
     /** @brief Update producer, should ONLY be called from monitor */
     int setProducer(const std::shared_ptr<Mlt::Producer> &producer, bool isActive, int position = -1);
+    int setProducer(const QString &file);
     QString frameToTime(int frames) const;
 
 public slots:
