@@ -55,6 +55,7 @@ class MonitorProxy : public QObject
     /** @brief: Contains the name of clip currently displayed in monitor
      * */
     Q_PROPERTY(int clipType MEMBER m_clipType NOTIFY clipTypeChanged)
+    Q_PROPERTY(int clipId MEMBER m_clipId NOTIFY clipIdChanged)
 
 public:
     MonitorProxy(GLWidget *parent);
@@ -84,9 +85,11 @@ public:
     QPoint zone() const;
     QImage extractFrame(int frame_position, const QString &path = QString(), int width = -1, int height = -1, bool useSourceProfile = false);
     Q_INVOKABLE QString toTimecode(int frames) const;
+    Q_INVOKABLE void startZoneMove();
+    Q_INVOKABLE void endZoneMove();
     Q_INVOKABLE double fps() const;
     QPoint profile();
-    void setClipProperties(ClipType::ProducerType type, bool hasAV, const QString clipName);
+    void setClipProperties(int clipId, ClipType::ProducerType type, bool hasAV, const QString clipName);
     void setAudioThumb(const QUrl thumbPath = QUrl());
 
 signals:
@@ -94,7 +97,8 @@ signals:
     void seekFinishedChanged();
     void requestSeek(int pos);
     void zoneChanged();
-    void saveZone();
+    void saveZone(const QPoint zone);
+    void saveZoneWithUndo(const QPoint, const QPoint&);
     void markerCommentChanged();
     void rulerHeightChanged();
     void addSnap(int);
@@ -108,6 +112,7 @@ signals:
     void clipHasAVChanged();
     void clipNameChanged();
     void clipTypeChanged();
+    void clipIdChanged();
     void audioThumbChanged();
     void profileChanged();
 
@@ -121,7 +126,9 @@ private:
     QString m_markerComment;
     QString m_clipName;
     int m_clipType;
+    int m_clipId;
     bool m_seekFinished;
+    QPoint m_undoZone;
 };
 
 #endif
