@@ -71,6 +71,7 @@ TimelineWidget::TimelineWidget(QWidget *parent)
     setFocusPolicy(Qt::StrongFocus);
     m_favEffects = new QMenu(i18n("Insert an effect..."), this);
     m_favCompositions = new QMenu(i18n("Insert a composition..."), this);
+    installEventFilter(this);
 }
 
 TimelineWidget::~TimelineWidget()
@@ -133,7 +134,7 @@ void TimelineWidget::setTimelineMenu(QMenu *clipMenu, QMenu *compositionMenu, QM
     connect(m_guideMenu, &QMenu::triggered, [&] (QAction *ac) {
         m_proxy->setPosition(ac->data().toInt());
     });
-    connect(m_headerMenu, &QMenu::triggered, [&] (QAction *ac) {
+    connect(m_thumbsMenu, &QMenu::triggered, [&] (QAction *ac) {
         m_proxy->setActiveTrackProperty(QStringLiteral("kdenlive:thumbs_format"), ac->data().toString());
     });
     // Fix qml focus issue
@@ -165,7 +166,7 @@ void TimelineWidget::setModel(const std::shared_ptr<TimelineItemModel> &model, M
     rootContext()->setContextProperty("guidesModel", pCore->projectManager()->current()->getGuideModel().get());
     rootContext()->setContextProperty("clipboard", new ClipboardProxy(this));
     QFont ft = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
-    ft.setPixelSize(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont).pixelSize());
+    ft.setPointSize(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont).pointSize());
     setFont(ft);
     rootContext()->setContextProperty("miniFont", font());
     const QStringList effs = sortedItems(KdenliveSettings::favorite_effects(), false).values();
@@ -226,11 +227,10 @@ void TimelineWidget::showHeaderMenu()
 {
     bool isAudio = m_proxy->isActiveTrackAudio();
     QList <QAction *> menuActions = m_headerMenu->actions();
-    QAction *showRec = nullptr;
+    QList <QAction *> audioActions;
     for (QAction *ac : menuActions) {
-        if (ac->data().toString() == QLatin1String("show_track_record")) {
-            showRec = ac;
-            break;
+        if (ac->data().toString() == QLatin1String("show_track_record") || ac->data().toString() == QLatin1String("separate_channels")) {
+            audioActions << ac;
         }
     }
     if (!isAudio) {
@@ -244,15 +244,17 @@ void TimelineWidget::showHeaderMenu()
             }
         }
         m_thumbsMenu->menuAction()->setVisible(true);
-        if (showRec) {
-            showRec->setVisible(false);
+        for (auto ac : audioActions) {
+            ac->setVisible(false);
         }
     } else {
         // Audio track
         m_thumbsMenu->menuAction()->setVisible(false);
-        if (showRec) {
-            showRec->setVisible(true);
-            showRec->setChecked(m_proxy->getActiveTrackProperty(QStringLiteral("kdenlive:audio_rec")).toInt() == 1);
+        for (auto ac : audioActions) {
+            ac->setVisible(true);
+            if (ac->data().toString() == QLatin1String("show_track_record")) {
+                ac->setChecked(m_proxy->getActiveTrackProperty(QStringLiteral("kdenlive:audio_rec")).toInt() == 1);
+            }
         }
     }
     m_headerMenu->popup(m_clickPos);
@@ -399,3 +401,30 @@ void TimelineWidget::endDrag()
         QMetaObject::invokeMethod(rootObject(), "endBinDrag");
     }
 }
+
+
+bool TimelineWidget::eventFilter(QObject *object, QEvent *event)
+{
+    switch(event->type()) {
+        case QEvent::Enter:
+            if (!hasFocus()) {
+                pCore->window()->focusTimeline(true, true);
+            }
+            break;
+        case QEvent::Leave:
+            if (!hasFocus()) {
+                pCore->window()->focusTimeline(false, true);
+            }
+            break;
+        case QEvent::FocusOut:
+            pCore->window()->focusTimeline(false, false);
+            break;
+        case QEvent::FocusIn:
+            pCore->window()->focusTimeline(true, false);
+            break;
+        default:
+            break;
+    }
+
+    return QQuickWidget::eventFilter(object, event);
+}
